@@ -1,9 +1,9 @@
 package BorderStyle::ASCII::None;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-11'; # DATE
+our $DATE = '2021-01-23'; # DATE
 our $DIST = 'BorderStyles-Standard'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use parent 'BorderStyleBase';
@@ -14,9 +14,9 @@ our %BORDER = (
     chars => [
         ['','','',''],     # 0
         ['','',''],        # 1
-        ['','','',''],     # 2
+        ['','','','',   '',''],     # 2
         ['','',''],        # 3
-        [' ','-','-',' '], # 4
+        ['','-','-','', '','','',''], # 4
         ['','','',''],     # 5
     ],
 );
@@ -36,7 +36,7 @@ BorderStyle::ASCII::None - No borders, but data row separator is still drawn usi
 
 =head1 VERSION
 
-This document describes version 0.002 of BorderStyle::ASCII::None (from Perl distribution BorderStyles-Standard), released on 2020-06-11.
+This document describes version 0.003 of BorderStyle::ASCII::None (from Perl distribution BorderStyles-Standard), released on 2021-01-23.
 
 =head1 SYNOPSIS
 
@@ -56,9 +56,9 @@ Sample output:
 
   ColumName1  ColumnNameB  ColumnNameC 
   row1A       row1B        row1C       
-  ---------------------------------------- 
+ ----------------------------------------
   row2A       row2B        row2C       
-  ---------------------------------------- 
+ ----------------------------------------
   row3A       row3B        row3C       
 
 
@@ -76,7 +76,7 @@ Source repository is at L<https://github.com/perlancar/perl-BorderStyles-Standar
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=BorderStyles-Standard>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-BorderStyles-Standard/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -96,7 +96,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
