@@ -1,9 +1,9 @@
 package BorderStyle::BoxChar::SingleLineOuterOnly;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-11'; # DATE
+our $DATE = '2021-01-23'; # DATE
 our $DIST = 'BorderStyles-Standard'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use parent 'BorderStyleBase';
@@ -14,9 +14,9 @@ our %BORDER = (
     chars => [
         ['l','q','q','k'], # 0
         ['x',' ','x'],     # 1
-        ['x',' ',' ','x'], # 2
+        ['x',' ',' ','x', ' ',' '], # 2
         ['x',' ','x'],     # 3
-        ['t','q','q','u'], # 4
+        ['t','q','q','u', 'q','q','q','q'], # 4
         ['m','q','q','j'], # 5
     ],
     box_chars => 1,
@@ -37,7 +37,7 @@ BorderStyle::BoxChar::SingleLineOuterOnly - Single line border with box-drawing
 
 =head1 VERSION
 
-This document describes version 0.002 of BorderStyle::BoxChar::SingleLineOuterOnly (from Perl distribution BorderStyles-Standard), released on 2020-06-11.
+This document describes version 0.003 of BorderStyle::BoxChar::SingleLineOuterOnly (from Perl distribution BorderStyles-Standard), released on 2021-01-23.
 
 =head1 SYNOPSIS
 
@@ -67,7 +67,7 @@ Source repository is at L<https://github.com/perlancar/perl-BorderStyles-Standar
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=BorderStyles-Standard>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-BorderStyles-Standard/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -91,7 +91,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
